module.exports = defineTest({
	description: 'forwards return values of getters'
});
